# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['EndpointArgs', 'Endpoint']

@pulumi.input_type
class EndpointArgs:
    def __init__(__self__, *,
                 display_name: pulumi.Input[_builtins.str],
                 parent: pulumi.Input[_builtins.str],
                 region: pulumi.Input[_builtins.str],
                 azure_private_endpoint_info: Optional[pulumi.Input['EndpointAzurePrivateEndpointInfoArgs']] = None):
        """
        The set of arguments for constructing a Endpoint resource.
        :param pulumi.Input[_builtins.str] display_name: The human-readable display name of this endpoint.
               The input should conform to RFC-1034, which restricts to letters, numbers, and hyphens,
               with the first character a letter, the last a letter or a number, and a 63 character maximum
        :param pulumi.Input[_builtins.str] parent: The parent resource name of the account under which the endpoint is created.
               Format: `accounts/{account_id}`
        :param pulumi.Input[_builtins.str] region: The cloud provider region where this endpoint is located
        :param pulumi.Input['EndpointAzurePrivateEndpointInfoArgs'] azure_private_endpoint_info: Info for an Azure private endpoint
        """
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "parent", parent)
        pulumi.set(__self__, "region", region)
        if azure_private_endpoint_info is not None:
            pulumi.set(__self__, "azure_private_endpoint_info", azure_private_endpoint_info)

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Input[_builtins.str]:
        """
        The human-readable display name of this endpoint.
        The input should conform to RFC-1034, which restricts to letters, numbers, and hyphens,
        with the first character a letter, the last a letter or a number, and a 63 character maximum
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "display_name", value)

    @_builtins.property
    @pulumi.getter
    def parent(self) -> pulumi.Input[_builtins.str]:
        """
        The parent resource name of the account under which the endpoint is created.
        Format: `accounts/{account_id}`
        """
        return pulumi.get(self, "parent")

    @parent.setter
    def parent(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "parent", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Input[_builtins.str]:
        """
        The cloud provider region where this endpoint is located
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter(name="azurePrivateEndpointInfo")
    def azure_private_endpoint_info(self) -> Optional[pulumi.Input['EndpointAzurePrivateEndpointInfoArgs']]:
        """
        Info for an Azure private endpoint
        """
        return pulumi.get(self, "azure_private_endpoint_info")

    @azure_private_endpoint_info.setter
    def azure_private_endpoint_info(self, value: Optional[pulumi.Input['EndpointAzurePrivateEndpointInfoArgs']]):
        pulumi.set(self, "azure_private_endpoint_info", value)


@pulumi.input_type
class _EndpointState:
    def __init__(__self__, *,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 azure_private_endpoint_info: Optional[pulumi.Input['EndpointAzurePrivateEndpointInfoArgs']] = None,
                 create_time: Optional[pulumi.Input[_builtins.str]] = None,
                 display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 endpoint_id: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 parent: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 state: Optional[pulumi.Input[_builtins.str]] = None,
                 use_case: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Endpoint resources.
        :param pulumi.Input[_builtins.str] account_id: (string) - The Databricks Account in which the endpoint object exists
        :param pulumi.Input['EndpointAzurePrivateEndpointInfoArgs'] azure_private_endpoint_info: Info for an Azure private endpoint
        :param pulumi.Input[_builtins.str] create_time: (string) - The timestamp when the endpoint was created. The timestamp is in RFC 3339 format in UTC timezone
        :param pulumi.Input[_builtins.str] display_name: The human-readable display name of this endpoint.
               The input should conform to RFC-1034, which restricts to letters, numbers, and hyphens,
               with the first character a letter, the last a letter or a number, and a 63 character maximum
        :param pulumi.Input[_builtins.str] endpoint_id: (string) - The unique identifier for this endpoint under the account. This field is a UUID generated by Databricks
        :param pulumi.Input[_builtins.str] name: (string) - The resource name of the endpoint, which uniquely identifies the endpoint
        :param pulumi.Input[_builtins.str] parent: The parent resource name of the account under which the endpoint is created.
               Format: `accounts/{account_id}`
        :param pulumi.Input[_builtins.str] region: The cloud provider region where this endpoint is located
        :param pulumi.Input[_builtins.str] state: (string) - The state of the endpoint. The endpoint can only be used if the state is `APPROVED`. Possible values are: `APPROVED`, `DISCONNECTED`, `FAILED`, `PENDING`
        :param pulumi.Input[_builtins.str] use_case: (string) - The use case that determines the type of network connectivity this endpoint provides.
               This field is automatically determined based on the endpoint configuration and cloud-specific settings. Possible values are: `SERVICE_DIRECT`
        """
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if azure_private_endpoint_info is not None:
            pulumi.set(__self__, "azure_private_endpoint_info", azure_private_endpoint_info)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if endpoint_id is not None:
            pulumi.set(__self__, "endpoint_id", endpoint_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if parent is not None:
            pulumi.set(__self__, "parent", parent)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if state is not None:
            pulumi.set(__self__, "state", state)
        if use_case is not None:
            pulumi.set(__self__, "use_case", use_case)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - The Databricks Account in which the endpoint object exists
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "account_id", value)

    @_builtins.property
    @pulumi.getter(name="azurePrivateEndpointInfo")
    def azure_private_endpoint_info(self) -> Optional[pulumi.Input['EndpointAzurePrivateEndpointInfoArgs']]:
        """
        Info for an Azure private endpoint
        """
        return pulumi.get(self, "azure_private_endpoint_info")

    @azure_private_endpoint_info.setter
    def azure_private_endpoint_info(self, value: Optional[pulumi.Input['EndpointAzurePrivateEndpointInfoArgs']]):
        pulumi.set(self, "azure_private_endpoint_info", value)

    @_builtins.property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - The timestamp when the endpoint was created. The timestamp is in RFC 3339 format in UTC timezone
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "create_time", value)

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The human-readable display name of this endpoint.
        The input should conform to RFC-1034, which restricts to letters, numbers, and hyphens,
        with the first character a letter, the last a letter or a number, and a 63 character maximum
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "display_name", value)

    @_builtins.property
    @pulumi.getter(name="endpointId")
    def endpoint_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - The unique identifier for this endpoint under the account. This field is a UUID generated by Databricks
        """
        return pulumi.get(self, "endpoint_id")

    @endpoint_id.setter
    def endpoint_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "endpoint_id", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - The resource name of the endpoint, which uniquely identifies the endpoint
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def parent(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The parent resource name of the account under which the endpoint is created.
        Format: `accounts/{account_id}`
        """
        return pulumi.get(self, "parent")

    @parent.setter
    def parent(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "parent", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The cloud provider region where this endpoint is located
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - The state of the endpoint. The endpoint can only be used if the state is `APPROVED`. Possible values are: `APPROVED`, `DISCONNECTED`, `FAILED`, `PENDING`
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "state", value)

    @_builtins.property
    @pulumi.getter(name="useCase")
    def use_case(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - The use case that determines the type of network connectivity this endpoint provides.
        This field is automatically determined based on the endpoint configuration and cloud-specific settings. Possible values are: `SERVICE_DIRECT`
        """
        return pulumi.get(self, "use_case")

    @use_case.setter
    def use_case(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "use_case", value)


@pulumi.type_token("databricks:index/endpoint:Endpoint")
class Endpoint(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 azure_private_endpoint_info: Optional[pulumi.Input[Union['EndpointAzurePrivateEndpointInfoArgs', 'EndpointAzurePrivateEndpointInfoArgsDict']]] = None,
                 display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 parent: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        [![Public Beta](https://img.shields.io/badge/Release_Stage-Public_Beta-orange)](https://docs.databricks.com/aws/en/release-notes/release-types)

        Endpoint resource manages network connectivity endpoints for private access to Databricks workspaces.

        > **Note** This resource can only be used with an account-level provider!

        ## Example Usage

        ### Example for Azure cloud
        This is an example for creating an endpoint in Azure cloud:
        ```python
        import pulumi
        import pulumi_databricks as databricks

        this = databricks.Endpoint("this",
            parent="accounts/123e4567-e89b-12d3-a456-426614174000",
            display_name="my-private-endpoint",
            region="westus",
            azure_private_endpoint_info={
                "private_endpoint_name": "my-pe",
                "private_endpoint_resource_guid": "12345678-1234-1234-1234-123456789abc",
            })
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['EndpointAzurePrivateEndpointInfoArgs', 'EndpointAzurePrivateEndpointInfoArgsDict']] azure_private_endpoint_info: Info for an Azure private endpoint
        :param pulumi.Input[_builtins.str] display_name: The human-readable display name of this endpoint.
               The input should conform to RFC-1034, which restricts to letters, numbers, and hyphens,
               with the first character a letter, the last a letter or a number, and a 63 character maximum
        :param pulumi.Input[_builtins.str] parent: The parent resource name of the account under which the endpoint is created.
               Format: `accounts/{account_id}`
        :param pulumi.Input[_builtins.str] region: The cloud provider region where this endpoint is located
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: EndpointArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        [![Public Beta](https://img.shields.io/badge/Release_Stage-Public_Beta-orange)](https://docs.databricks.com/aws/en/release-notes/release-types)

        Endpoint resource manages network connectivity endpoints for private access to Databricks workspaces.

        > **Note** This resource can only be used with an account-level provider!

        ## Example Usage

        ### Example for Azure cloud
        This is an example for creating an endpoint in Azure cloud:
        ```python
        import pulumi
        import pulumi_databricks as databricks

        this = databricks.Endpoint("this",
            parent="accounts/123e4567-e89b-12d3-a456-426614174000",
            display_name="my-private-endpoint",
            region="westus",
            azure_private_endpoint_info={
                "private_endpoint_name": "my-pe",
                "private_endpoint_resource_guid": "12345678-1234-1234-1234-123456789abc",
            })
        ```

        :param str resource_name: The name of the resource.
        :param EndpointArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(EndpointArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 azure_private_endpoint_info: Optional[pulumi.Input[Union['EndpointAzurePrivateEndpointInfoArgs', 'EndpointAzurePrivateEndpointInfoArgsDict']]] = None,
                 display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 parent: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = EndpointArgs.__new__(EndpointArgs)

            __props__.__dict__["azure_private_endpoint_info"] = azure_private_endpoint_info
            if display_name is None and not opts.urn:
                raise TypeError("Missing required property 'display_name'")
            __props__.__dict__["display_name"] = display_name
            if parent is None and not opts.urn:
                raise TypeError("Missing required property 'parent'")
            __props__.__dict__["parent"] = parent
            if region is None and not opts.urn:
                raise TypeError("Missing required property 'region'")
            __props__.__dict__["region"] = region
            __props__.__dict__["account_id"] = None
            __props__.__dict__["create_time"] = None
            __props__.__dict__["endpoint_id"] = None
            __props__.__dict__["name"] = None
            __props__.__dict__["state"] = None
            __props__.__dict__["use_case"] = None
        super(Endpoint, __self__).__init__(
            'databricks:index/endpoint:Endpoint',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_id: Optional[pulumi.Input[_builtins.str]] = None,
            azure_private_endpoint_info: Optional[pulumi.Input[Union['EndpointAzurePrivateEndpointInfoArgs', 'EndpointAzurePrivateEndpointInfoArgsDict']]] = None,
            create_time: Optional[pulumi.Input[_builtins.str]] = None,
            display_name: Optional[pulumi.Input[_builtins.str]] = None,
            endpoint_id: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            parent: Optional[pulumi.Input[_builtins.str]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None,
            state: Optional[pulumi.Input[_builtins.str]] = None,
            use_case: Optional[pulumi.Input[_builtins.str]] = None) -> 'Endpoint':
        """
        Get an existing Endpoint resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] account_id: (string) - The Databricks Account in which the endpoint object exists
        :param pulumi.Input[Union['EndpointAzurePrivateEndpointInfoArgs', 'EndpointAzurePrivateEndpointInfoArgsDict']] azure_private_endpoint_info: Info for an Azure private endpoint
        :param pulumi.Input[_builtins.str] create_time: (string) - The timestamp when the endpoint was created. The timestamp is in RFC 3339 format in UTC timezone
        :param pulumi.Input[_builtins.str] display_name: The human-readable display name of this endpoint.
               The input should conform to RFC-1034, which restricts to letters, numbers, and hyphens,
               with the first character a letter, the last a letter or a number, and a 63 character maximum
        :param pulumi.Input[_builtins.str] endpoint_id: (string) - The unique identifier for this endpoint under the account. This field is a UUID generated by Databricks
        :param pulumi.Input[_builtins.str] name: (string) - The resource name of the endpoint, which uniquely identifies the endpoint
        :param pulumi.Input[_builtins.str] parent: The parent resource name of the account under which the endpoint is created.
               Format: `accounts/{account_id}`
        :param pulumi.Input[_builtins.str] region: The cloud provider region where this endpoint is located
        :param pulumi.Input[_builtins.str] state: (string) - The state of the endpoint. The endpoint can only be used if the state is `APPROVED`. Possible values are: `APPROVED`, `DISCONNECTED`, `FAILED`, `PENDING`
        :param pulumi.Input[_builtins.str] use_case: (string) - The use case that determines the type of network connectivity this endpoint provides.
               This field is automatically determined based on the endpoint configuration and cloud-specific settings. Possible values are: `SERVICE_DIRECT`
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _EndpointState.__new__(_EndpointState)

        __props__.__dict__["account_id"] = account_id
        __props__.__dict__["azure_private_endpoint_info"] = azure_private_endpoint_info
        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["endpoint_id"] = endpoint_id
        __props__.__dict__["name"] = name
        __props__.__dict__["parent"] = parent
        __props__.__dict__["region"] = region
        __props__.__dict__["state"] = state
        __props__.__dict__["use_case"] = use_case
        return Endpoint(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - The Databricks Account in which the endpoint object exists
        """
        return pulumi.get(self, "account_id")

    @_builtins.property
    @pulumi.getter(name="azurePrivateEndpointInfo")
    def azure_private_endpoint_info(self) -> pulumi.Output[Optional['outputs.EndpointAzurePrivateEndpointInfo']]:
        """
        Info for an Azure private endpoint
        """
        return pulumi.get(self, "azure_private_endpoint_info")

    @_builtins.property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - The timestamp when the endpoint was created. The timestamp is in RFC 3339 format in UTC timezone
        """
        return pulumi.get(self, "create_time")

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[_builtins.str]:
        """
        The human-readable display name of this endpoint.
        The input should conform to RFC-1034, which restricts to letters, numbers, and hyphens,
        with the first character a letter, the last a letter or a number, and a 63 character maximum
        """
        return pulumi.get(self, "display_name")

    @_builtins.property
    @pulumi.getter(name="endpointId")
    def endpoint_id(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - The unique identifier for this endpoint under the account. This field is a UUID generated by Databricks
        """
        return pulumi.get(self, "endpoint_id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - The resource name of the endpoint, which uniquely identifies the endpoint
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def parent(self) -> pulumi.Output[_builtins.str]:
        """
        The parent resource name of the account under which the endpoint is created.
        Format: `accounts/{account_id}`
        """
        return pulumi.get(self, "parent")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[_builtins.str]:
        """
        The cloud provider region where this endpoint is located
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter
    def state(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - The state of the endpoint. The endpoint can only be used if the state is `APPROVED`. Possible values are: `APPROVED`, `DISCONNECTED`, `FAILED`, `PENDING`
        """
        return pulumi.get(self, "state")

    @_builtins.property
    @pulumi.getter(name="useCase")
    def use_case(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - The use case that determines the type of network connectivity this endpoint provides.
        This field is automatically determined based on the endpoint configuration and cloud-specific settings. Possible values are: `SERVICE_DIRECT`
        """
        return pulumi.get(self, "use_case")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['WarehousesDefaultWarehouseOverrideArgs', 'WarehousesDefaultWarehouseOverride']

@pulumi.input_type
class WarehousesDefaultWarehouseOverrideArgs:
    def __init__(__self__, *,
                 default_warehouse_override_id: pulumi.Input[_builtins.str],
                 type: pulumi.Input[_builtins.str],
                 provider_config: Optional[pulumi.Input['WarehousesDefaultWarehouseOverrideProviderConfigArgs']] = None,
                 warehouse_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a WarehousesDefaultWarehouseOverride resource.
        :param pulumi.Input[_builtins.str] default_warehouse_override_id: The ID component of the resource name (user ID)
        :param pulumi.Input[_builtins.str] type: The type of override behavior. Possible values are: `CUSTOM`, `LAST_SELECTED`
        :param pulumi.Input['WarehousesDefaultWarehouseOverrideProviderConfigArgs'] provider_config: Configure the provider for management through account provider.
        :param pulumi.Input[_builtins.str] warehouse_id: The specific warehouse ID when type is CUSTOM.
               Not set for LAST_SELECTED type
        """
        pulumi.set(__self__, "default_warehouse_override_id", default_warehouse_override_id)
        pulumi.set(__self__, "type", type)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)
        if warehouse_id is not None:
            pulumi.set(__self__, "warehouse_id", warehouse_id)

    @_builtins.property
    @pulumi.getter(name="defaultWarehouseOverrideId")
    def default_warehouse_override_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID component of the resource name (user ID)
        """
        return pulumi.get(self, "default_warehouse_override_id")

    @default_warehouse_override_id.setter
    def default_warehouse_override_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "default_warehouse_override_id", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Input[_builtins.str]:
        """
        The type of override behavior. Possible values are: `CUSTOM`, `LAST_SELECTED`
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "type", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['WarehousesDefaultWarehouseOverrideProviderConfigArgs']]:
        """
        Configure the provider for management through account provider.
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['WarehousesDefaultWarehouseOverrideProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)

    @_builtins.property
    @pulumi.getter(name="warehouseId")
    def warehouse_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The specific warehouse ID when type is CUSTOM.
        Not set for LAST_SELECTED type
        """
        return pulumi.get(self, "warehouse_id")

    @warehouse_id.setter
    def warehouse_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "warehouse_id", value)


@pulumi.input_type
class _WarehousesDefaultWarehouseOverrideState:
    def __init__(__self__, *,
                 default_warehouse_override_id: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input['WarehousesDefaultWarehouseOverrideProviderConfigArgs']] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 warehouse_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering WarehousesDefaultWarehouseOverride resources.
        :param pulumi.Input[_builtins.str] default_warehouse_override_id: The ID component of the resource name (user ID)
        :param pulumi.Input[_builtins.str] name: (string) - The resource name of the default warehouse override.
               Format: default-warehouse-overrides/{default_warehouse_override_id}
        :param pulumi.Input['WarehousesDefaultWarehouseOverrideProviderConfigArgs'] provider_config: Configure the provider for management through account provider.
        :param pulumi.Input[_builtins.str] type: The type of override behavior. Possible values are: `CUSTOM`, `LAST_SELECTED`
        :param pulumi.Input[_builtins.str] warehouse_id: The specific warehouse ID when type is CUSTOM.
               Not set for LAST_SELECTED type
        """
        if default_warehouse_override_id is not None:
            pulumi.set(__self__, "default_warehouse_override_id", default_warehouse_override_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if warehouse_id is not None:
            pulumi.set(__self__, "warehouse_id", warehouse_id)

    @_builtins.property
    @pulumi.getter(name="defaultWarehouseOverrideId")
    def default_warehouse_override_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID component of the resource name (user ID)
        """
        return pulumi.get(self, "default_warehouse_override_id")

    @default_warehouse_override_id.setter
    def default_warehouse_override_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "default_warehouse_override_id", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - The resource name of the default warehouse override.
        Format: default-warehouse-overrides/{default_warehouse_override_id}
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['WarehousesDefaultWarehouseOverrideProviderConfigArgs']]:
        """
        Configure the provider for management through account provider.
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['WarehousesDefaultWarehouseOverrideProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The type of override behavior. Possible values are: `CUSTOM`, `LAST_SELECTED`
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "type", value)

    @_builtins.property
    @pulumi.getter(name="warehouseId")
    def warehouse_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The specific warehouse ID when type is CUSTOM.
        Not set for LAST_SELECTED type
        """
        return pulumi.get(self, "warehouse_id")

    @warehouse_id.setter
    def warehouse_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "warehouse_id", value)


@pulumi.type_token("databricks:index/warehousesDefaultWarehouseOverride:WarehousesDefaultWarehouseOverride")
class WarehousesDefaultWarehouseOverride(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 default_warehouse_override_id: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input[Union['WarehousesDefaultWarehouseOverrideProviderConfigArgs', 'WarehousesDefaultWarehouseOverrideProviderConfigArgsDict']]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 warehouse_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        [![Public Beta](https://img.shields.io/badge/Release_Stage-Public_Beta-orange)](https://docs.databricks.com/aws/en/release-notes/release-types)

        The Default Warehouse Override resource allows you to configure a user's default warehouse selection behavior in Databricks SQL. This resource enables customization of how a user's default warehouse is selected for SQL operations.

        Users can configure their default warehouse to either:
        - Remember their last-selected warehouse (`LAST_SELECTED` type)
        - Use a specific warehouse (`CUSTOM` type with a warehouse ID)

        > **Note** The `default_warehouse_override_id` field represents the **user ID** of the user whose default warehouse behavior is being configured.

        ## Example Usage

        ### Basic Example with Last Selected Type
        This example creates a default warehouse override that remembers the user's last-selected warehouse.
        The `default_warehouse_override_id` represents the user ID of the target user:

        ```python
        import pulumi
        import pulumi_databricks as databricks

        last_selected = databricks.index.DefaultWarehouseOverride("last_selected",
            default_warehouse_override_id=example.id,
            type=LAST_SELECTED)
        ```

        ### Custom Warehouse Example
        This example creates a default warehouse override that always uses a specific warehouse:

        ```python
        import pulumi
        import pulumi_databricks as databricks

        custom = databricks.index.DefaultWarehouseOverride("custom",
            default_warehouse_override_id=example.id,
            type=CUSTOM,
            warehouse_id=example_databricks_sql_endpoint.id)
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] default_warehouse_override_id: The ID component of the resource name (user ID)
        :param pulumi.Input[Union['WarehousesDefaultWarehouseOverrideProviderConfigArgs', 'WarehousesDefaultWarehouseOverrideProviderConfigArgsDict']] provider_config: Configure the provider for management through account provider.
        :param pulumi.Input[_builtins.str] type: The type of override behavior. Possible values are: `CUSTOM`, `LAST_SELECTED`
        :param pulumi.Input[_builtins.str] warehouse_id: The specific warehouse ID when type is CUSTOM.
               Not set for LAST_SELECTED type
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: WarehousesDefaultWarehouseOverrideArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        [![Public Beta](https://img.shields.io/badge/Release_Stage-Public_Beta-orange)](https://docs.databricks.com/aws/en/release-notes/release-types)

        The Default Warehouse Override resource allows you to configure a user's default warehouse selection behavior in Databricks SQL. This resource enables customization of how a user's default warehouse is selected for SQL operations.

        Users can configure their default warehouse to either:
        - Remember their last-selected warehouse (`LAST_SELECTED` type)
        - Use a specific warehouse (`CUSTOM` type with a warehouse ID)

        > **Note** The `default_warehouse_override_id` field represents the **user ID** of the user whose default warehouse behavior is being configured.

        ## Example Usage

        ### Basic Example with Last Selected Type
        This example creates a default warehouse override that remembers the user's last-selected warehouse.
        The `default_warehouse_override_id` represents the user ID of the target user:

        ```python
        import pulumi
        import pulumi_databricks as databricks

        last_selected = databricks.index.DefaultWarehouseOverride("last_selected",
            default_warehouse_override_id=example.id,
            type=LAST_SELECTED)
        ```

        ### Custom Warehouse Example
        This example creates a default warehouse override that always uses a specific warehouse:

        ```python
        import pulumi
        import pulumi_databricks as databricks

        custom = databricks.index.DefaultWarehouseOverride("custom",
            default_warehouse_override_id=example.id,
            type=CUSTOM,
            warehouse_id=example_databricks_sql_endpoint.id)
        ```

        :param str resource_name: The name of the resource.
        :param WarehousesDefaultWarehouseOverrideArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(WarehousesDefaultWarehouseOverrideArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 default_warehouse_override_id: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input[Union['WarehousesDefaultWarehouseOverrideProviderConfigArgs', 'WarehousesDefaultWarehouseOverrideProviderConfigArgsDict']]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 warehouse_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = WarehousesDefaultWarehouseOverrideArgs.__new__(WarehousesDefaultWarehouseOverrideArgs)

            if default_warehouse_override_id is None and not opts.urn:
                raise TypeError("Missing required property 'default_warehouse_override_id'")
            __props__.__dict__["default_warehouse_override_id"] = default_warehouse_override_id
            __props__.__dict__["provider_config"] = provider_config
            if type is None and not opts.urn:
                raise TypeError("Missing required property 'type'")
            __props__.__dict__["type"] = type
            __props__.__dict__["warehouse_id"] = warehouse_id
            __props__.__dict__["name"] = None
        super(WarehousesDefaultWarehouseOverride, __self__).__init__(
            'databricks:index/warehousesDefaultWarehouseOverride:WarehousesDefaultWarehouseOverride',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            default_warehouse_override_id: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            provider_config: Optional[pulumi.Input[Union['WarehousesDefaultWarehouseOverrideProviderConfigArgs', 'WarehousesDefaultWarehouseOverrideProviderConfigArgsDict']]] = None,
            type: Optional[pulumi.Input[_builtins.str]] = None,
            warehouse_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'WarehousesDefaultWarehouseOverride':
        """
        Get an existing WarehousesDefaultWarehouseOverride resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] default_warehouse_override_id: The ID component of the resource name (user ID)
        :param pulumi.Input[_builtins.str] name: (string) - The resource name of the default warehouse override.
               Format: default-warehouse-overrides/{default_warehouse_override_id}
        :param pulumi.Input[Union['WarehousesDefaultWarehouseOverrideProviderConfigArgs', 'WarehousesDefaultWarehouseOverrideProviderConfigArgsDict']] provider_config: Configure the provider for management through account provider.
        :param pulumi.Input[_builtins.str] type: The type of override behavior. Possible values are: `CUSTOM`, `LAST_SELECTED`
        :param pulumi.Input[_builtins.str] warehouse_id: The specific warehouse ID when type is CUSTOM.
               Not set for LAST_SELECTED type
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _WarehousesDefaultWarehouseOverrideState.__new__(_WarehousesDefaultWarehouseOverrideState)

        __props__.__dict__["default_warehouse_override_id"] = default_warehouse_override_id
        __props__.__dict__["name"] = name
        __props__.__dict__["provider_config"] = provider_config
        __props__.__dict__["type"] = type
        __props__.__dict__["warehouse_id"] = warehouse_id
        return WarehousesDefaultWarehouseOverride(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="defaultWarehouseOverrideId")
    def default_warehouse_override_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID component of the resource name (user ID)
        """
        return pulumi.get(self, "default_warehouse_override_id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - The resource name of the default warehouse override.
        Format: default-warehouse-overrides/{default_warehouse_override_id}
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> pulumi.Output[Optional['outputs.WarehousesDefaultWarehouseOverrideProviderConfig']]:
        """
        Configure the provider for management through account provider.
        """
        return pulumi.get(self, "provider_config")

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Output[_builtins.str]:
        """
        The type of override behavior. Possible values are: `CUSTOM`, `LAST_SELECTED`
        """
        return pulumi.get(self, "type")

    @_builtins.property
    @pulumi.getter(name="warehouseId")
    def warehouse_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The specific warehouse ID when type is CUSTOM.
        Not set for LAST_SELECTED type
        """
        return pulumi.get(self, "warehouse_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['AppArgs', 'App']

@pulumi.input_type
class AppArgs:
    def __init__(__self__, *,
                 budget_policy_id: Optional[pulumi.Input[_builtins.str]] = None,
                 compute_size: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 git_repository: Optional[pulumi.Input['AppGitRepositoryArgs']] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 no_compute: Optional[pulumi.Input[_builtins.bool]] = None,
                 provider_config: Optional[pulumi.Input['AppProviderConfigArgs']] = None,
                 resources: Optional[pulumi.Input[Sequence[pulumi.Input['AppResourceArgs']]]] = None,
                 space: Optional[pulumi.Input[_builtins.str]] = None,
                 telemetry_export_destinations: Optional[pulumi.Input[Sequence[pulumi.Input['AppTelemetryExportDestinationArgs']]]] = None,
                 usage_policy_id: Optional[pulumi.Input[_builtins.str]] = None,
                 user_api_scopes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        The set of arguments for constructing a App resource.
        :param pulumi.Input[_builtins.str] budget_policy_id: The Budget Policy ID set for this resource.
        :param pulumi.Input[_builtins.str] compute_size: A string specifying compute size for the App. Possible values are `MEDIUM`, `LARGE`.
        :param pulumi.Input[_builtins.str] description: The description of the app.
        :param pulumi.Input[_builtins.str] name: The name of the app. The name must contain only lowercase alphanumeric characters and hyphens. It must be unique within the workspace.
        :param pulumi.Input[Sequence[pulumi.Input['AppResourceArgs']]] resources: A list of resources that the app have access to.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] user_api_scopes: A list of api scopes granted to the user access token.
        """
        if budget_policy_id is not None:
            pulumi.set(__self__, "budget_policy_id", budget_policy_id)
        if compute_size is not None:
            pulumi.set(__self__, "compute_size", compute_size)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if git_repository is not None:
            pulumi.set(__self__, "git_repository", git_repository)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if no_compute is not None:
            pulumi.set(__self__, "no_compute", no_compute)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)
        if resources is not None:
            pulumi.set(__self__, "resources", resources)
        if space is not None:
            pulumi.set(__self__, "space", space)
        if telemetry_export_destinations is not None:
            pulumi.set(__self__, "telemetry_export_destinations", telemetry_export_destinations)
        if usage_policy_id is not None:
            pulumi.set(__self__, "usage_policy_id", usage_policy_id)
        if user_api_scopes is not None:
            pulumi.set(__self__, "user_api_scopes", user_api_scopes)

    @_builtins.property
    @pulumi.getter(name="budgetPolicyId")
    def budget_policy_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Budget Policy ID set for this resource.
        """
        return pulumi.get(self, "budget_policy_id")

    @budget_policy_id.setter
    def budget_policy_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "budget_policy_id", value)

    @_builtins.property
    @pulumi.getter(name="computeSize")
    def compute_size(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A string specifying compute size for the App. Possible values are `MEDIUM`, `LARGE`.
        """
        return pulumi.get(self, "compute_size")

    @compute_size.setter
    def compute_size(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "compute_size", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The description of the app.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="gitRepository")
    def git_repository(self) -> Optional[pulumi.Input['AppGitRepositoryArgs']]:
        return pulumi.get(self, "git_repository")

    @git_repository.setter
    def git_repository(self, value: Optional[pulumi.Input['AppGitRepositoryArgs']]):
        pulumi.set(self, "git_repository", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the app. The name must contain only lowercase alphanumeric characters and hyphens. It must be unique within the workspace.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="noCompute")
    def no_compute(self) -> Optional[pulumi.Input[_builtins.bool]]:
        return pulumi.get(self, "no_compute")

    @no_compute.setter
    def no_compute(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "no_compute", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['AppProviderConfigArgs']]:
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['AppProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)

    @_builtins.property
    @pulumi.getter
    def resources(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AppResourceArgs']]]]:
        """
        A list of resources that the app have access to.
        """
        return pulumi.get(self, "resources")

    @resources.setter
    def resources(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AppResourceArgs']]]]):
        pulumi.set(self, "resources", value)

    @_builtins.property
    @pulumi.getter
    def space(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "space")

    @space.setter
    def space(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "space", value)

    @_builtins.property
    @pulumi.getter(name="telemetryExportDestinations")
    def telemetry_export_destinations(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AppTelemetryExportDestinationArgs']]]]:
        return pulumi.get(self, "telemetry_export_destinations")

    @telemetry_export_destinations.setter
    def telemetry_export_destinations(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AppTelemetryExportDestinationArgs']]]]):
        pulumi.set(self, "telemetry_export_destinations", value)

    @_builtins.property
    @pulumi.getter(name="usagePolicyId")
    def usage_policy_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "usage_policy_id")

    @usage_policy_id.setter
    def usage_policy_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "usage_policy_id", value)

    @_builtins.property
    @pulumi.getter(name="userApiScopes")
    def user_api_scopes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        A list of api scopes granted to the user access token.
        """
        return pulumi.get(self, "user_api_scopes")

    @user_api_scopes.setter
    def user_api_scopes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "user_api_scopes", value)


@pulumi.input_type
class _AppState:
    def __init__(__self__, *,
                 active_deployment: Optional[pulumi.Input['AppActiveDeploymentArgs']] = None,
                 app_status: Optional[pulumi.Input['AppAppStatusArgs']] = None,
                 budget_policy_id: Optional[pulumi.Input[_builtins.str]] = None,
                 compute_size: Optional[pulumi.Input[_builtins.str]] = None,
                 compute_status: Optional[pulumi.Input['AppComputeStatusArgs']] = None,
                 create_time: Optional[pulumi.Input[_builtins.str]] = None,
                 creator: Optional[pulumi.Input[_builtins.str]] = None,
                 default_source_code_path: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 effective_budget_policy_id: Optional[pulumi.Input[_builtins.str]] = None,
                 effective_usage_policy_id: Optional[pulumi.Input[_builtins.str]] = None,
                 effective_user_api_scopes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 git_repository: Optional[pulumi.Input['AppGitRepositoryArgs']] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 no_compute: Optional[pulumi.Input[_builtins.bool]] = None,
                 oauth2_app_client_id: Optional[pulumi.Input[_builtins.str]] = None,
                 oauth2_app_integration_id: Optional[pulumi.Input[_builtins.str]] = None,
                 pending_deployment: Optional[pulumi.Input['AppPendingDeploymentArgs']] = None,
                 provider_config: Optional[pulumi.Input['AppProviderConfigArgs']] = None,
                 resources: Optional[pulumi.Input[Sequence[pulumi.Input['AppResourceArgs']]]] = None,
                 service_principal_client_id: Optional[pulumi.Input[_builtins.str]] = None,
                 service_principal_id: Optional[pulumi.Input[_builtins.int]] = None,
                 service_principal_name: Optional[pulumi.Input[_builtins.str]] = None,
                 space: Optional[pulumi.Input[_builtins.str]] = None,
                 telemetry_export_destinations: Optional[pulumi.Input[Sequence[pulumi.Input['AppTelemetryExportDestinationArgs']]]] = None,
                 update_time: Optional[pulumi.Input[_builtins.str]] = None,
                 updater: Optional[pulumi.Input[_builtins.str]] = None,
                 url: Optional[pulumi.Input[_builtins.str]] = None,
                 usage_policy_id: Optional[pulumi.Input[_builtins.str]] = None,
                 user_api_scopes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering App resources.
        :param pulumi.Input['AppAppStatusArgs'] app_status: attribute
        :param pulumi.Input[_builtins.str] budget_policy_id: The Budget Policy ID set for this resource.
        :param pulumi.Input[_builtins.str] compute_size: A string specifying compute size for the App. Possible values are `MEDIUM`, `LARGE`.
        :param pulumi.Input['AppComputeStatusArgs'] compute_status: attribute
        :param pulumi.Input[_builtins.str] create_time: The creation time of the app.
        :param pulumi.Input[_builtins.str] creator: The email of the user that created the app.
        :param pulumi.Input[_builtins.str] default_source_code_path: The default workspace file system path of the source code from which app deployment are created. This field tracks the workspace source code path of the last active deployment.
        :param pulumi.Input[_builtins.str] description: The description of the app.
        :param pulumi.Input[_builtins.str] effective_budget_policy_id: The effective budget policy ID.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] effective_user_api_scopes: A list of effective api scopes granted to the user access token.
        :param pulumi.Input[_builtins.str] name: The name of the app. The name must contain only lowercase alphanumeric characters and hyphens. It must be unique within the workspace.
        :param pulumi.Input[Sequence[pulumi.Input['AppResourceArgs']]] resources: A list of resources that the app have access to.
        :param pulumi.Input[_builtins.str] service_principal_client_id: client_id (application_id) of the app service principal
        :param pulumi.Input[_builtins.int] service_principal_id: id of the app service principal
        :param pulumi.Input[_builtins.str] service_principal_name: name of the app service principal
        :param pulumi.Input[_builtins.str] update_time: The update time of the app.
        :param pulumi.Input[_builtins.str] updater: The email of the user that last updated the app.
        :param pulumi.Input[_builtins.str] url: The URL of the app once it is deployed.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] user_api_scopes: A list of api scopes granted to the user access token.
        """
        if active_deployment is not None:
            pulumi.set(__self__, "active_deployment", active_deployment)
        if app_status is not None:
            pulumi.set(__self__, "app_status", app_status)
        if budget_policy_id is not None:
            pulumi.set(__self__, "budget_policy_id", budget_policy_id)
        if compute_size is not None:
            pulumi.set(__self__, "compute_size", compute_size)
        if compute_status is not None:
            pulumi.set(__self__, "compute_status", compute_status)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if creator is not None:
            pulumi.set(__self__, "creator", creator)
        if default_source_code_path is not None:
            pulumi.set(__self__, "default_source_code_path", default_source_code_path)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if effective_budget_policy_id is not None:
            pulumi.set(__self__, "effective_budget_policy_id", effective_budget_policy_id)
        if effective_usage_policy_id is not None:
            pulumi.set(__self__, "effective_usage_policy_id", effective_usage_policy_id)
        if effective_user_api_scopes is not None:
            pulumi.set(__self__, "effective_user_api_scopes", effective_user_api_scopes)
        if git_repository is not None:
            pulumi.set(__self__, "git_repository", git_repository)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if no_compute is not None:
            pulumi.set(__self__, "no_compute", no_compute)
        if oauth2_app_client_id is not None:
            pulumi.set(__self__, "oauth2_app_client_id", oauth2_app_client_id)
        if oauth2_app_integration_id is not None:
            pulumi.set(__self__, "oauth2_app_integration_id", oauth2_app_integration_id)
        if pending_deployment is not None:
            pulumi.set(__self__, "pending_deployment", pending_deployment)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)
        if resources is not None:
            pulumi.set(__self__, "resources", resources)
        if service_principal_client_id is not None:
            pulumi.set(__self__, "service_principal_client_id", service_principal_client_id)
        if service_principal_id is not None:
            pulumi.set(__self__, "service_principal_id", service_principal_id)
        if service_principal_name is not None:
            pulumi.set(__self__, "service_principal_name", service_principal_name)
        if space is not None:
            pulumi.set(__self__, "space", space)
        if telemetry_export_destinations is not None:
            pulumi.set(__self__, "telemetry_export_destinations", telemetry_export_destinations)
        if update_time is not None:
            pulumi.set(__self__, "update_time", update_time)
        if updater is not None:
            pulumi.set(__self__, "updater", updater)
        if url is not None:
            pulumi.set(__self__, "url", url)
        if usage_policy_id is not None:
            pulumi.set(__self__, "usage_policy_id", usage_policy_id)
        if user_api_scopes is not None:
            pulumi.set(__self__, "user_api_scopes", user_api_scopes)

    @_builtins.property
    @pulumi.getter(name="activeDeployment")
    def active_deployment(self) -> Optional[pulumi.Input['AppActiveDeploymentArgs']]:
        return pulumi.get(self, "active_deployment")

    @active_deployment.setter
    def active_deployment(self, value: Optional[pulumi.Input['AppActiveDeploymentArgs']]):
        pulumi.set(self, "active_deployment", value)

    @_builtins.property
    @pulumi.getter(name="appStatus")
    def app_status(self) -> Optional[pulumi.Input['AppAppStatusArgs']]:
        """
        attribute
        """
        return pulumi.get(self, "app_status")

    @app_status.setter
    def app_status(self, value: Optional[pulumi.Input['AppAppStatusArgs']]):
        pulumi.set(self, "app_status", value)

    @_builtins.property
    @pulumi.getter(name="budgetPolicyId")
    def budget_policy_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Budget Policy ID set for this resource.
        """
        return pulumi.get(self, "budget_policy_id")

    @budget_policy_id.setter
    def budget_policy_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "budget_policy_id", value)

    @_builtins.property
    @pulumi.getter(name="computeSize")
    def compute_size(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A string specifying compute size for the App. Possible values are `MEDIUM`, `LARGE`.
        """
        return pulumi.get(self, "compute_size")

    @compute_size.setter
    def compute_size(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "compute_size", value)

    @_builtins.property
    @pulumi.getter(name="computeStatus")
    def compute_status(self) -> Optional[pulumi.Input['AppComputeStatusArgs']]:
        """
        attribute
        """
        return pulumi.get(self, "compute_status")

    @compute_status.setter
    def compute_status(self, value: Optional[pulumi.Input['AppComputeStatusArgs']]):
        pulumi.set(self, "compute_status", value)

    @_builtins.property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The creation time of the app.
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "create_time", value)

    @_builtins.property
    @pulumi.getter
    def creator(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The email of the user that created the app.
        """
        return pulumi.get(self, "creator")

    @creator.setter
    def creator(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "creator", value)

    @_builtins.property
    @pulumi.getter(name="defaultSourceCodePath")
    def default_source_code_path(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The default workspace file system path of the source code from which app deployment are created. This field tracks the workspace source code path of the last active deployment.
        """
        return pulumi.get(self, "default_source_code_path")

    @default_source_code_path.setter
    def default_source_code_path(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "default_source_code_path", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The description of the app.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="effectiveBudgetPolicyId")
    def effective_budget_policy_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The effective budget policy ID.
        """
        return pulumi.get(self, "effective_budget_policy_id")

    @effective_budget_policy_id.setter
    def effective_budget_policy_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "effective_budget_policy_id", value)

    @_builtins.property
    @pulumi.getter(name="effectiveUsagePolicyId")
    def effective_usage_policy_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "effective_usage_policy_id")

    @effective_usage_policy_id.setter
    def effective_usage_policy_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "effective_usage_policy_id", value)

    @_builtins.property
    @pulumi.getter(name="effectiveUserApiScopes")
    def effective_user_api_scopes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        A list of effective api scopes granted to the user access token.
        """
        return pulumi.get(self, "effective_user_api_scopes")

    @effective_user_api_scopes.setter
    def effective_user_api_scopes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "effective_user_api_scopes", value)

    @_builtins.property
    @pulumi.getter(name="gitRepository")
    def git_repository(self) -> Optional[pulumi.Input['AppGitRepositoryArgs']]:
        return pulumi.get(self, "git_repository")

    @git_repository.setter
    def git_repository(self, value: Optional[pulumi.Input['AppGitRepositoryArgs']]):
        pulumi.set(self, "git_repository", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the app. The name must contain only lowercase alphanumeric characters and hyphens. It must be unique within the workspace.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="noCompute")
    def no_compute(self) -> Optional[pulumi.Input[_builtins.bool]]:
        return pulumi.get(self, "no_compute")

    @no_compute.setter
    def no_compute(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "no_compute", value)

    @_builtins.property
    @pulumi.getter(name="oauth2AppClientId")
    def oauth2_app_client_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "oauth2_app_client_id")

    @oauth2_app_client_id.setter
    def oauth2_app_client_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "oauth2_app_client_id", value)

    @_builtins.property
    @pulumi.getter(name="oauth2AppIntegrationId")
    def oauth2_app_integration_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "oauth2_app_integration_id")

    @oauth2_app_integration_id.setter
    def oauth2_app_integration_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "oauth2_app_integration_id", value)

    @_builtins.property
    @pulumi.getter(name="pendingDeployment")
    def pending_deployment(self) -> Optional[pulumi.Input['AppPendingDeploymentArgs']]:
        return pulumi.get(self, "pending_deployment")

    @pending_deployment.setter
    def pending_deployment(self, value: Optional[pulumi.Input['AppPendingDeploymentArgs']]):
        pulumi.set(self, "pending_deployment", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['AppProviderConfigArgs']]:
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['AppProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)

    @_builtins.property
    @pulumi.getter
    def resources(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AppResourceArgs']]]]:
        """
        A list of resources that the app have access to.
        """
        return pulumi.get(self, "resources")

    @resources.setter
    def resources(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AppResourceArgs']]]]):
        pulumi.set(self, "resources", value)

    @_builtins.property
    @pulumi.getter(name="servicePrincipalClientId")
    def service_principal_client_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        client_id (application_id) of the app service principal
        """
        return pulumi.get(self, "service_principal_client_id")

    @service_principal_client_id.setter
    def service_principal_client_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "service_principal_client_id", value)

    @_builtins.property
    @pulumi.getter(name="servicePrincipalId")
    def service_principal_id(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        id of the app service principal
        """
        return pulumi.get(self, "service_principal_id")

    @service_principal_id.setter
    def service_principal_id(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "service_principal_id", value)

    @_builtins.property
    @pulumi.getter(name="servicePrincipalName")
    def service_principal_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        name of the app service principal
        """
        return pulumi.get(self, "service_principal_name")

    @service_principal_name.setter
    def service_principal_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "service_principal_name", value)

    @_builtins.property
    @pulumi.getter
    def space(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "space")

    @space.setter
    def space(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "space", value)

    @_builtins.property
    @pulumi.getter(name="telemetryExportDestinations")
    def telemetry_export_destinations(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AppTelemetryExportDestinationArgs']]]]:
        return pulumi.get(self, "telemetry_export_destinations")

    @telemetry_export_destinations.setter
    def telemetry_export_destinations(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AppTelemetryExportDestinationArgs']]]]):
        pulumi.set(self, "telemetry_export_destinations", value)

    @_builtins.property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The update time of the app.
        """
        return pulumi.get(self, "update_time")

    @update_time.setter
    def update_time(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "update_time", value)

    @_builtins.property
    @pulumi.getter
    def updater(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The email of the user that last updated the app.
        """
        return pulumi.get(self, "updater")

    @updater.setter
    def updater(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "updater", value)

    @_builtins.property
    @pulumi.getter
    def url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The URL of the app once it is deployed.
        """
        return pulumi.get(self, "url")

    @url.setter
    def url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "url", value)

    @_builtins.property
    @pulumi.getter(name="usagePolicyId")
    def usage_policy_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "usage_policy_id")

    @usage_policy_id.setter
    def usage_policy_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "usage_policy_id", value)

    @_builtins.property
    @pulumi.getter(name="userApiScopes")
    def user_api_scopes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        A list of api scopes granted to the user access token.
        """
        return pulumi.get(self, "user_api_scopes")

    @user_api_scopes.setter
    def user_api_scopes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "user_api_scopes", value)


@pulumi.type_token("databricks:index/app:App")
class App(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 budget_policy_id: Optional[pulumi.Input[_builtins.str]] = None,
                 compute_size: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 git_repository: Optional[pulumi.Input[Union['AppGitRepositoryArgs', 'AppGitRepositoryArgsDict']]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 no_compute: Optional[pulumi.Input[_builtins.bool]] = None,
                 provider_config: Optional[pulumi.Input[Union['AppProviderConfigArgs', 'AppProviderConfigArgsDict']]] = None,
                 resources: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AppResourceArgs', 'AppResourceArgsDict']]]]] = None,
                 space: Optional[pulumi.Input[_builtins.str]] = None,
                 telemetry_export_destinations: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AppTelemetryExportDestinationArgs', 'AppTelemetryExportDestinationArgsDict']]]]] = None,
                 usage_policy_id: Optional[pulumi.Input[_builtins.str]] = None,
                 user_api_scopes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        """
        [Databricks Apps](https://docs.databricks.com/en/dev-tools/databricks-apps/index.html) run directly on a customer's Databricks instance, integrate with their data, use and extend Databricks services, and enable users to interact through single sign-on. This resource creates the application but does not handle app deployment, which should be handled separately as part of your CI/CD pipeline.

        > This resource can only be used with a workspace-level provider!

        ## Example Usage

        ```python
        import pulumi
        import pulumi_databricks as databricks

        this = databricks.App("this",
            name="my-custom-app",
            description="My app",
            resources=[
                {
                    "name": "sql-warehouse",
                    "sql_warehouse": {
                        "id": "e9ca293f79a74b5c",
                        "permission": "CAN_MANAGE",
                    },
                },
                {
                    "name": "serving-endpoint",
                    "serving_endpoint": {
                        "name": "databricks-meta-llama-3-1-70b-instruct",
                        "permission": "CAN_MANAGE",
                    },
                },
                {
                    "name": "job",
                    "job": {
                        "id": "1234",
                        "permission": "CAN_MANAGE",
                    },
                },
            ])
        ```

        ## Related Resources

        The following resources are used in the same context:

        * SqlEndpoint to manage Databricks SQL [Endpoints](https://docs.databricks.com/sql/admin/sql-endpoints.html).
        * ModelServing to serve this model on a Databricks serving endpoint.
        * Secret to manage [secrets](https://docs.databricks.com/security/secrets/index.html#secrets-user-guide) in Databricks workspace.
        * Job to manage [Databricks Jobs](https://docs.databricks.com/jobs.html) to run non-interactive code.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] budget_policy_id: The Budget Policy ID set for this resource.
        :param pulumi.Input[_builtins.str] compute_size: A string specifying compute size for the App. Possible values are `MEDIUM`, `LARGE`.
        :param pulumi.Input[_builtins.str] description: The description of the app.
        :param pulumi.Input[_builtins.str] name: The name of the app. The name must contain only lowercase alphanumeric characters and hyphens. It must be unique within the workspace.
        :param pulumi.Input[Sequence[pulumi.Input[Union['AppResourceArgs', 'AppResourceArgsDict']]]] resources: A list of resources that the app have access to.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] user_api_scopes: A list of api scopes granted to the user access token.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[AppArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        [Databricks Apps](https://docs.databricks.com/en/dev-tools/databricks-apps/index.html) run directly on a customer's Databricks instance, integrate with their data, use and extend Databricks services, and enable users to interact through single sign-on. This resource creates the application but does not handle app deployment, which should be handled separately as part of your CI/CD pipeline.

        > This resource can only be used with a workspace-level provider!

        ## Example Usage

        ```python
        import pulumi
        import pulumi_databricks as databricks

        this = databricks.App("this",
            name="my-custom-app",
            description="My app",
            resources=[
                {
                    "name": "sql-warehouse",
                    "sql_warehouse": {
                        "id": "e9ca293f79a74b5c",
                        "permission": "CAN_MANAGE",
                    },
                },
                {
                    "name": "serving-endpoint",
                    "serving_endpoint": {
                        "name": "databricks-meta-llama-3-1-70b-instruct",
                        "permission": "CAN_MANAGE",
                    },
                },
                {
                    "name": "job",
                    "job": {
                        "id": "1234",
                        "permission": "CAN_MANAGE",
                    },
                },
            ])
        ```

        ## Related Resources

        The following resources are used in the same context:

        * SqlEndpoint to manage Databricks SQL [Endpoints](https://docs.databricks.com/sql/admin/sql-endpoints.html).
        * ModelServing to serve this model on a Databricks serving endpoint.
        * Secret to manage [secrets](https://docs.databricks.com/security/secrets/index.html#secrets-user-guide) in Databricks workspace.
        * Job to manage [Databricks Jobs](https://docs.databricks.com/jobs.html) to run non-interactive code.

        :param str resource_name: The name of the resource.
        :param AppArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AppArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 budget_policy_id: Optional[pulumi.Input[_builtins.str]] = None,
                 compute_size: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 git_repository: Optional[pulumi.Input[Union['AppGitRepositoryArgs', 'AppGitRepositoryArgsDict']]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 no_compute: Optional[pulumi.Input[_builtins.bool]] = None,
                 provider_config: Optional[pulumi.Input[Union['AppProviderConfigArgs', 'AppProviderConfigArgsDict']]] = None,
                 resources: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AppResourceArgs', 'AppResourceArgsDict']]]]] = None,
                 space: Optional[pulumi.Input[_builtins.str]] = None,
                 telemetry_export_destinations: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AppTelemetryExportDestinationArgs', 'AppTelemetryExportDestinationArgsDict']]]]] = None,
                 usage_policy_id: Optional[pulumi.Input[_builtins.str]] = None,
                 user_api_scopes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AppArgs.__new__(AppArgs)

            __props__.__dict__["budget_policy_id"] = budget_policy_id
            __props__.__dict__["compute_size"] = compute_size
            __props__.__dict__["description"] = description
            __props__.__dict__["git_repository"] = git_repository
            __props__.__dict__["name"] = name
            __props__.__dict__["no_compute"] = no_compute
            __props__.__dict__["provider_config"] = provider_config
            __props__.__dict__["resources"] = resources
            __props__.__dict__["space"] = space
            __props__.__dict__["telemetry_export_destinations"] = telemetry_export_destinations
            __props__.__dict__["usage_policy_id"] = usage_policy_id
            __props__.__dict__["user_api_scopes"] = user_api_scopes
            __props__.__dict__["active_deployment"] = None
            __props__.__dict__["app_status"] = None
            __props__.__dict__["compute_status"] = None
            __props__.__dict__["create_time"] = None
            __props__.__dict__["creator"] = None
            __props__.__dict__["default_source_code_path"] = None
            __props__.__dict__["effective_budget_policy_id"] = None
            __props__.__dict__["effective_usage_policy_id"] = None
            __props__.__dict__["effective_user_api_scopes"] = None
            __props__.__dict__["oauth2_app_client_id"] = None
            __props__.__dict__["oauth2_app_integration_id"] = None
            __props__.__dict__["pending_deployment"] = None
            __props__.__dict__["service_principal_client_id"] = None
            __props__.__dict__["service_principal_id"] = None
            __props__.__dict__["service_principal_name"] = None
            __props__.__dict__["update_time"] = None
            __props__.__dict__["updater"] = None
            __props__.__dict__["url"] = None
        super(App, __self__).__init__(
            'databricks:index/app:App',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            active_deployment: Optional[pulumi.Input[Union['AppActiveDeploymentArgs', 'AppActiveDeploymentArgsDict']]] = None,
            app_status: Optional[pulumi.Input[Union['AppAppStatusArgs', 'AppAppStatusArgsDict']]] = None,
            budget_policy_id: Optional[pulumi.Input[_builtins.str]] = None,
            compute_size: Optional[pulumi.Input[_builtins.str]] = None,
            compute_status: Optional[pulumi.Input[Union['AppComputeStatusArgs', 'AppComputeStatusArgsDict']]] = None,
            create_time: Optional[pulumi.Input[_builtins.str]] = None,
            creator: Optional[pulumi.Input[_builtins.str]] = None,
            default_source_code_path: Optional[pulumi.Input[_builtins.str]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            effective_budget_policy_id: Optional[pulumi.Input[_builtins.str]] = None,
            effective_usage_policy_id: Optional[pulumi.Input[_builtins.str]] = None,
            effective_user_api_scopes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            git_repository: Optional[pulumi.Input[Union['AppGitRepositoryArgs', 'AppGitRepositoryArgsDict']]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            no_compute: Optional[pulumi.Input[_builtins.bool]] = None,
            oauth2_app_client_id: Optional[pulumi.Input[_builtins.str]] = None,
            oauth2_app_integration_id: Optional[pulumi.Input[_builtins.str]] = None,
            pending_deployment: Optional[pulumi.Input[Union['AppPendingDeploymentArgs', 'AppPendingDeploymentArgsDict']]] = None,
            provider_config: Optional[pulumi.Input[Union['AppProviderConfigArgs', 'AppProviderConfigArgsDict']]] = None,
            resources: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AppResourceArgs', 'AppResourceArgsDict']]]]] = None,
            service_principal_client_id: Optional[pulumi.Input[_builtins.str]] = None,
            service_principal_id: Optional[pulumi.Input[_builtins.int]] = None,
            service_principal_name: Optional[pulumi.Input[_builtins.str]] = None,
            space: Optional[pulumi.Input[_builtins.str]] = None,
            telemetry_export_destinations: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AppTelemetryExportDestinationArgs', 'AppTelemetryExportDestinationArgsDict']]]]] = None,
            update_time: Optional[pulumi.Input[_builtins.str]] = None,
            updater: Optional[pulumi.Input[_builtins.str]] = None,
            url: Optional[pulumi.Input[_builtins.str]] = None,
            usage_policy_id: Optional[pulumi.Input[_builtins.str]] = None,
            user_api_scopes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None) -> 'App':
        """
        Get an existing App resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['AppAppStatusArgs', 'AppAppStatusArgsDict']] app_status: attribute
        :param pulumi.Input[_builtins.str] budget_policy_id: The Budget Policy ID set for this resource.
        :param pulumi.Input[_builtins.str] compute_size: A string specifying compute size for the App. Possible values are `MEDIUM`, `LARGE`.
        :param pulumi.Input[Union['AppComputeStatusArgs', 'AppComputeStatusArgsDict']] compute_status: attribute
        :param pulumi.Input[_builtins.str] create_time: The creation time of the app.
        :param pulumi.Input[_builtins.str] creator: The email of the user that created the app.
        :param pulumi.Input[_builtins.str] default_source_code_path: The default workspace file system path of the source code from which app deployment are created. This field tracks the workspace source code path of the last active deployment.
        :param pulumi.Input[_builtins.str] description: The description of the app.
        :param pulumi.Input[_builtins.str] effective_budget_policy_id: The effective budget policy ID.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] effective_user_api_scopes: A list of effective api scopes granted to the user access token.
        :param pulumi.Input[_builtins.str] name: The name of the app. The name must contain only lowercase alphanumeric characters and hyphens. It must be unique within the workspace.
        :param pulumi.Input[Sequence[pulumi.Input[Union['AppResourceArgs', 'AppResourceArgsDict']]]] resources: A list of resources that the app have access to.
        :param pulumi.Input[_builtins.str] service_principal_client_id: client_id (application_id) of the app service principal
        :param pulumi.Input[_builtins.int] service_principal_id: id of the app service principal
        :param pulumi.Input[_builtins.str] service_principal_name: name of the app service principal
        :param pulumi.Input[_builtins.str] update_time: The update time of the app.
        :param pulumi.Input[_builtins.str] updater: The email of the user that last updated the app.
        :param pulumi.Input[_builtins.str] url: The URL of the app once it is deployed.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] user_api_scopes: A list of api scopes granted to the user access token.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AppState.__new__(_AppState)

        __props__.__dict__["active_deployment"] = active_deployment
        __props__.__dict__["app_status"] = app_status
        __props__.__dict__["budget_policy_id"] = budget_policy_id
        __props__.__dict__["compute_size"] = compute_size
        __props__.__dict__["compute_status"] = compute_status
        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["creator"] = creator
        __props__.__dict__["default_source_code_path"] = default_source_code_path
        __props__.__dict__["description"] = description
        __props__.__dict__["effective_budget_policy_id"] = effective_budget_policy_id
        __props__.__dict__["effective_usage_policy_id"] = effective_usage_policy_id
        __props__.__dict__["effective_user_api_scopes"] = effective_user_api_scopes
        __props__.__dict__["git_repository"] = git_repository
        __props__.__dict__["name"] = name
        __props__.__dict__["no_compute"] = no_compute
        __props__.__dict__["oauth2_app_client_id"] = oauth2_app_client_id
        __props__.__dict__["oauth2_app_integration_id"] = oauth2_app_integration_id
        __props__.__dict__["pending_deployment"] = pending_deployment
        __props__.__dict__["provider_config"] = provider_config
        __props__.__dict__["resources"] = resources
        __props__.__dict__["service_principal_client_id"] = service_principal_client_id
        __props__.__dict__["service_principal_id"] = service_principal_id
        __props__.__dict__["service_principal_name"] = service_principal_name
        __props__.__dict__["space"] = space
        __props__.__dict__["telemetry_export_destinations"] = telemetry_export_destinations
        __props__.__dict__["update_time"] = update_time
        __props__.__dict__["updater"] = updater
        __props__.__dict__["url"] = url
        __props__.__dict__["usage_policy_id"] = usage_policy_id
        __props__.__dict__["user_api_scopes"] = user_api_scopes
        return App(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="activeDeployment")
    def active_deployment(self) -> pulumi.Output['outputs.AppActiveDeployment']:
        return pulumi.get(self, "active_deployment")

    @_builtins.property
    @pulumi.getter(name="appStatus")
    def app_status(self) -> pulumi.Output['outputs.AppAppStatus']:
        """
        attribute
        """
        return pulumi.get(self, "app_status")

    @_builtins.property
    @pulumi.getter(name="budgetPolicyId")
    def budget_policy_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The Budget Policy ID set for this resource.
        """
        return pulumi.get(self, "budget_policy_id")

    @_builtins.property
    @pulumi.getter(name="computeSize")
    def compute_size(self) -> pulumi.Output[_builtins.str]:
        """
        A string specifying compute size for the App. Possible values are `MEDIUM`, `LARGE`.
        """
        return pulumi.get(self, "compute_size")

    @_builtins.property
    @pulumi.getter(name="computeStatus")
    def compute_status(self) -> pulumi.Output['outputs.AppComputeStatus']:
        """
        attribute
        """
        return pulumi.get(self, "compute_status")

    @_builtins.property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[_builtins.str]:
        """
        The creation time of the app.
        """
        return pulumi.get(self, "create_time")

    @_builtins.property
    @pulumi.getter
    def creator(self) -> pulumi.Output[_builtins.str]:
        """
        The email of the user that created the app.
        """
        return pulumi.get(self, "creator")

    @_builtins.property
    @pulumi.getter(name="defaultSourceCodePath")
    def default_source_code_path(self) -> pulumi.Output[_builtins.str]:
        """
        The default workspace file system path of the source code from which app deployment are created. This field tracks the workspace source code path of the last active deployment.
        """
        return pulumi.get(self, "default_source_code_path")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The description of the app.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="effectiveBudgetPolicyId")
    def effective_budget_policy_id(self) -> pulumi.Output[_builtins.str]:
        """
        The effective budget policy ID.
        """
        return pulumi.get(self, "effective_budget_policy_id")

    @_builtins.property
    @pulumi.getter(name="effectiveUsagePolicyId")
    def effective_usage_policy_id(self) -> pulumi.Output[_builtins.str]:
        return pulumi.get(self, "effective_usage_policy_id")

    @_builtins.property
    @pulumi.getter(name="effectiveUserApiScopes")
    def effective_user_api_scopes(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        A list of effective api scopes granted to the user access token.
        """
        return pulumi.get(self, "effective_user_api_scopes")

    @_builtins.property
    @pulumi.getter(name="gitRepository")
    def git_repository(self) -> pulumi.Output[Optional['outputs.AppGitRepository']]:
        return pulumi.get(self, "git_repository")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the app. The name must contain only lowercase alphanumeric characters and hyphens. It must be unique within the workspace.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="noCompute")
    def no_compute(self) -> pulumi.Output[Optional[_builtins.bool]]:
        return pulumi.get(self, "no_compute")

    @_builtins.property
    @pulumi.getter(name="oauth2AppClientId")
    def oauth2_app_client_id(self) -> pulumi.Output[_builtins.str]:
        return pulumi.get(self, "oauth2_app_client_id")

    @_builtins.property
    @pulumi.getter(name="oauth2AppIntegrationId")
    def oauth2_app_integration_id(self) -> pulumi.Output[_builtins.str]:
        return pulumi.get(self, "oauth2_app_integration_id")

    @_builtins.property
    @pulumi.getter(name="pendingDeployment")
    def pending_deployment(self) -> pulumi.Output['outputs.AppPendingDeployment']:
        return pulumi.get(self, "pending_deployment")

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> pulumi.Output[Optional['outputs.AppProviderConfig']]:
        return pulumi.get(self, "provider_config")

    @_builtins.property
    @pulumi.getter
    def resources(self) -> pulumi.Output[Optional[Sequence['outputs.AppResource']]]:
        """
        A list of resources that the app have access to.
        """
        return pulumi.get(self, "resources")

    @_builtins.property
    @pulumi.getter(name="servicePrincipalClientId")
    def service_principal_client_id(self) -> pulumi.Output[_builtins.str]:
        """
        client_id (application_id) of the app service principal
        """
        return pulumi.get(self, "service_principal_client_id")

    @_builtins.property
    @pulumi.getter(name="servicePrincipalId")
    def service_principal_id(self) -> pulumi.Output[_builtins.int]:
        """
        id of the app service principal
        """
        return pulumi.get(self, "service_principal_id")

    @_builtins.property
    @pulumi.getter(name="servicePrincipalName")
    def service_principal_name(self) -> pulumi.Output[_builtins.str]:
        """
        name of the app service principal
        """
        return pulumi.get(self, "service_principal_name")

    @_builtins.property
    @pulumi.getter
    def space(self) -> pulumi.Output[Optional[_builtins.str]]:
        return pulumi.get(self, "space")

    @_builtins.property
    @pulumi.getter(name="telemetryExportDestinations")
    def telemetry_export_destinations(self) -> pulumi.Output[Optional[Sequence['outputs.AppTelemetryExportDestination']]]:
        return pulumi.get(self, "telemetry_export_destinations")

    @_builtins.property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> pulumi.Output[_builtins.str]:
        """
        The update time of the app.
        """
        return pulumi.get(self, "update_time")

    @_builtins.property
    @pulumi.getter
    def updater(self) -> pulumi.Output[_builtins.str]:
        """
        The email of the user that last updated the app.
        """
        return pulumi.get(self, "updater")

    @_builtins.property
    @pulumi.getter
    def url(self) -> pulumi.Output[_builtins.str]:
        """
        The URL of the app once it is deployed.
        """
        return pulumi.get(self, "url")

    @_builtins.property
    @pulumi.getter(name="usagePolicyId")
    def usage_policy_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        return pulumi.get(self, "usage_policy_id")

    @_builtins.property
    @pulumi.getter(name="userApiScopes")
    def user_api_scopes(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        A list of api scopes granted to the user access token.
        """
        return pulumi.get(self, "user_api_scopes")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetRegisteredModelResult',
    'AwaitableGetRegisteredModelResult',
    'get_registered_model',
    'get_registered_model_output',
]

@pulumi.output_type
class GetRegisteredModelResult:
    """
    A collection of values returned by getRegisteredModel.
    """
    def __init__(__self__, full_name=None, id=None, include_aliases=None, include_browse=None, model_infos=None, provider_config=None):
        if full_name and not isinstance(full_name, str):
            raise TypeError("Expected argument 'full_name' to be a str")
        pulumi.set(__self__, "full_name", full_name)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if include_aliases and not isinstance(include_aliases, bool):
            raise TypeError("Expected argument 'include_aliases' to be a bool")
        pulumi.set(__self__, "include_aliases", include_aliases)
        if include_browse and not isinstance(include_browse, bool):
            raise TypeError("Expected argument 'include_browse' to be a bool")
        pulumi.set(__self__, "include_browse", include_browse)
        if model_infos and not isinstance(model_infos, list):
            raise TypeError("Expected argument 'model_infos' to be a list")
        pulumi.set(__self__, "model_infos", model_infos)
        if provider_config and not isinstance(provider_config, dict):
            raise TypeError("Expected argument 'provider_config' to be a dict")
        pulumi.set(__self__, "provider_config", provider_config)

    @_builtins.property
    @pulumi.getter(name="fullName")
    def full_name(self) -> _builtins.str:
        """
        The fully-qualified name of the registered model (`catalog_name.schema_name.name`).
        """
        return pulumi.get(self, "full_name")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="includeAliases")
    def include_aliases(self) -> Optional[_builtins.bool]:
        return pulumi.get(self, "include_aliases")

    @_builtins.property
    @pulumi.getter(name="includeBrowse")
    def include_browse(self) -> Optional[_builtins.bool]:
        return pulumi.get(self, "include_browse")

    @_builtins.property
    @pulumi.getter(name="modelInfos")
    def model_infos(self) -> Sequence['outputs.GetRegisteredModelModelInfoResult']:
        """
        block with information about the model in Unity Catalog:
        """
        return pulumi.get(self, "model_infos")

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional['outputs.GetRegisteredModelProviderConfigResult']:
        return pulumi.get(self, "provider_config")


class AwaitableGetRegisteredModelResult(GetRegisteredModelResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetRegisteredModelResult(
            full_name=self.full_name,
            id=self.id,
            include_aliases=self.include_aliases,
            include_browse=self.include_browse,
            model_infos=self.model_infos,
            provider_config=self.provider_config)


def get_registered_model(full_name: Optional[_builtins.str] = None,
                         include_aliases: Optional[_builtins.bool] = None,
                         include_browse: Optional[_builtins.bool] = None,
                         model_infos: Optional[Sequence[Union['GetRegisteredModelModelInfoArgs', 'GetRegisteredModelModelInfoArgsDict']]] = None,
                         provider_config: Optional[Union['GetRegisteredModelProviderConfigArgs', 'GetRegisteredModelProviderConfigArgsDict']] = None,
                         opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetRegisteredModelResult:
    """
    This resource allows you to get information about [Model in Unity Catalog](https://docs.databricks.com/en/mlflow/models-in-uc.html) in Databricks.

    > This data source can only be used with a workspace-level provider!

    ## Example Usage

    ```python
    import pulumi
    import pulumi_databricks as databricks

    this = databricks.get_registered_model(full_name="main.default.my_model")
    ```

    ## Related Resources

    The following resources are often used in the same context:

    * RegisteredModel resource to manage models within Unity Catalog.
    * ModelServing to serve this model on a Databricks serving endpoint.
    * MlflowExperiment to manage [MLflow experiments](https://docs.databricks.com/data/data-sources/mlflow-experiment.html) in Databricks.


    :param _builtins.str full_name: The fully-qualified name of the registered model (`catalog_name.schema_name.name`).
    :param _builtins.bool include_aliases: flag to specify if list of aliases should be included into output.
    :param _builtins.bool include_browse: flag to specify if include registered models in the response for which the principal can only access selective metadata for.
    :param Sequence[Union['GetRegisteredModelModelInfoArgs', 'GetRegisteredModelModelInfoArgsDict']] model_infos: block with information about the model in Unity Catalog:
    """
    __args__ = dict()
    __args__['fullName'] = full_name
    __args__['includeAliases'] = include_aliases
    __args__['includeBrowse'] = include_browse
    __args__['modelInfos'] = model_infos
    __args__['providerConfig'] = provider_config
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('databricks:index/getRegisteredModel:getRegisteredModel', __args__, opts=opts, typ=GetRegisteredModelResult).value

    return AwaitableGetRegisteredModelResult(
        full_name=pulumi.get(__ret__, 'full_name'),
        id=pulumi.get(__ret__, 'id'),
        include_aliases=pulumi.get(__ret__, 'include_aliases'),
        include_browse=pulumi.get(__ret__, 'include_browse'),
        model_infos=pulumi.get(__ret__, 'model_infos'),
        provider_config=pulumi.get(__ret__, 'provider_config'))
def get_registered_model_output(full_name: Optional[pulumi.Input[_builtins.str]] = None,
                                include_aliases: Optional[pulumi.Input[Optional[_builtins.bool]]] = None,
                                include_browse: Optional[pulumi.Input[Optional[_builtins.bool]]] = None,
                                model_infos: Optional[pulumi.Input[Optional[Sequence[Union['GetRegisteredModelModelInfoArgs', 'GetRegisteredModelModelInfoArgsDict']]]]] = None,
                                provider_config: Optional[pulumi.Input[Optional[Union['GetRegisteredModelProviderConfigArgs', 'GetRegisteredModelProviderConfigArgsDict']]]] = None,
                                opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetRegisteredModelResult]:
    """
    This resource allows you to get information about [Model in Unity Catalog](https://docs.databricks.com/en/mlflow/models-in-uc.html) in Databricks.

    > This data source can only be used with a workspace-level provider!

    ## Example Usage

    ```python
    import pulumi
    import pulumi_databricks as databricks

    this = databricks.get_registered_model(full_name="main.default.my_model")
    ```

    ## Related Resources

    The following resources are often used in the same context:

    * RegisteredModel resource to manage models within Unity Catalog.
    * ModelServing to serve this model on a Databricks serving endpoint.
    * MlflowExperiment to manage [MLflow experiments](https://docs.databricks.com/data/data-sources/mlflow-experiment.html) in Databricks.


    :param _builtins.str full_name: The fully-qualified name of the registered model (`catalog_name.schema_name.name`).
    :param _builtins.bool include_aliases: flag to specify if list of aliases should be included into output.
    :param _builtins.bool include_browse: flag to specify if include registered models in the response for which the principal can only access selective metadata for.
    :param Sequence[Union['GetRegisteredModelModelInfoArgs', 'GetRegisteredModelModelInfoArgsDict']] model_infos: block with information about the model in Unity Catalog:
    """
    __args__ = dict()
    __args__['fullName'] = full_name
    __args__['includeAliases'] = include_aliases
    __args__['includeBrowse'] = include_browse
    __args__['modelInfos'] = model_infos
    __args__['providerConfig'] = provider_config
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('databricks:index/getRegisteredModel:getRegisteredModel', __args__, opts=opts, typ=GetRegisteredModelResult)
    return __ret__.apply(lambda __response__: GetRegisteredModelResult(
        full_name=pulumi.get(__response__, 'full_name'),
        id=pulumi.get(__response__, 'id'),
        include_aliases=pulumi.get(__response__, 'include_aliases'),
        include_browse=pulumi.get(__response__, 'include_browse'),
        model_infos=pulumi.get(__response__, 'model_infos'),
        provider_config=pulumi.get(__response__, 'provider_config')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['FileArgs', 'File']

@pulumi.input_type
class FileArgs:
    def __init__(__self__, *,
                 path: pulumi.Input[_builtins.str],
                 content_base64: Optional[pulumi.Input[_builtins.str]] = None,
                 md5: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input['FileProviderConfigArgs']] = None,
                 remote_file_modified: Optional[pulumi.Input[_builtins.bool]] = None,
                 source: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a File resource.
        :param pulumi.Input[_builtins.str] path: The path of the file in which you wish to save. For example, `/Volumes/main/default/volume1/file.txt`.
        :param pulumi.Input[_builtins.str] content_base64: Contents in base 64 format. Conflicts with `source`.
        :param pulumi.Input['FileProviderConfigArgs'] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
        :param pulumi.Input[_builtins.str] source: The full absolute path to the file. Conflicts with `content_base64`.
        """
        pulumi.set(__self__, "path", path)
        if content_base64 is not None:
            pulumi.set(__self__, "content_base64", content_base64)
        if md5 is not None:
            pulumi.set(__self__, "md5", md5)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)
        if remote_file_modified is not None:
            pulumi.set(__self__, "remote_file_modified", remote_file_modified)
        if source is not None:
            pulumi.set(__self__, "source", source)

    @_builtins.property
    @pulumi.getter
    def path(self) -> pulumi.Input[_builtins.str]:
        """
        The path of the file in which you wish to save. For example, `/Volumes/main/default/volume1/file.txt`.
        """
        return pulumi.get(self, "path")

    @path.setter
    def path(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "path", value)

    @_builtins.property
    @pulumi.getter(name="contentBase64")
    def content_base64(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Contents in base 64 format. Conflicts with `source`.
        """
        return pulumi.get(self, "content_base64")

    @content_base64.setter
    def content_base64(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "content_base64", value)

    @_builtins.property
    @pulumi.getter
    def md5(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "md5")

    @md5.setter
    def md5(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "md5", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['FileProviderConfigArgs']]:
        """
        Configure the provider for management through account provider. This block consists of the following fields:
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['FileProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)

    @_builtins.property
    @pulumi.getter(name="remoteFileModified")
    def remote_file_modified(self) -> Optional[pulumi.Input[_builtins.bool]]:
        return pulumi.get(self, "remote_file_modified")

    @remote_file_modified.setter
    def remote_file_modified(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "remote_file_modified", value)

    @_builtins.property
    @pulumi.getter
    def source(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The full absolute path to the file. Conflicts with `content_base64`.
        """
        return pulumi.get(self, "source")

    @source.setter
    def source(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "source", value)


@pulumi.input_type
class _FileState:
    def __init__(__self__, *,
                 content_base64: Optional[pulumi.Input[_builtins.str]] = None,
                 file_size: Optional[pulumi.Input[_builtins.int]] = None,
                 md5: Optional[pulumi.Input[_builtins.str]] = None,
                 modification_time: Optional[pulumi.Input[_builtins.str]] = None,
                 path: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input['FileProviderConfigArgs']] = None,
                 remote_file_modified: Optional[pulumi.Input[_builtins.bool]] = None,
                 source: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering File resources.
        :param pulumi.Input[_builtins.str] content_base64: Contents in base 64 format. Conflicts with `source`.
        :param pulumi.Input[_builtins.int] file_size: The file size of the file that is being tracked by this resource in bytes.
        :param pulumi.Input[_builtins.str] modification_time: The last time stamp when the file was modified
        :param pulumi.Input[_builtins.str] path: The path of the file in which you wish to save. For example, `/Volumes/main/default/volume1/file.txt`.
        :param pulumi.Input['FileProviderConfigArgs'] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
        :param pulumi.Input[_builtins.str] source: The full absolute path to the file. Conflicts with `content_base64`.
        """
        if content_base64 is not None:
            pulumi.set(__self__, "content_base64", content_base64)
        if file_size is not None:
            pulumi.set(__self__, "file_size", file_size)
        if md5 is not None:
            pulumi.set(__self__, "md5", md5)
        if modification_time is not None:
            pulumi.set(__self__, "modification_time", modification_time)
        if path is not None:
            pulumi.set(__self__, "path", path)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)
        if remote_file_modified is not None:
            pulumi.set(__self__, "remote_file_modified", remote_file_modified)
        if source is not None:
            pulumi.set(__self__, "source", source)

    @_builtins.property
    @pulumi.getter(name="contentBase64")
    def content_base64(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Contents in base 64 format. Conflicts with `source`.
        """
        return pulumi.get(self, "content_base64")

    @content_base64.setter
    def content_base64(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "content_base64", value)

    @_builtins.property
    @pulumi.getter(name="fileSize")
    def file_size(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The file size of the file that is being tracked by this resource in bytes.
        """
        return pulumi.get(self, "file_size")

    @file_size.setter
    def file_size(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "file_size", value)

    @_builtins.property
    @pulumi.getter
    def md5(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "md5")

    @md5.setter
    def md5(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "md5", value)

    @_builtins.property
    @pulumi.getter(name="modificationTime")
    def modification_time(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The last time stamp when the file was modified
        """
        return pulumi.get(self, "modification_time")

    @modification_time.setter
    def modification_time(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "modification_time", value)

    @_builtins.property
    @pulumi.getter
    def path(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The path of the file in which you wish to save. For example, `/Volumes/main/default/volume1/file.txt`.
        """
        return pulumi.get(self, "path")

    @path.setter
    def path(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "path", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['FileProviderConfigArgs']]:
        """
        Configure the provider for management through account provider. This block consists of the following fields:
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['FileProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)

    @_builtins.property
    @pulumi.getter(name="remoteFileModified")
    def remote_file_modified(self) -> Optional[pulumi.Input[_builtins.bool]]:
        return pulumi.get(self, "remote_file_modified")

    @remote_file_modified.setter
    def remote_file_modified(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "remote_file_modified", value)

    @_builtins.property
    @pulumi.getter
    def source(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The full absolute path to the file. Conflicts with `content_base64`.
        """
        return pulumi.get(self, "source")

    @source.setter
    def source(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "source", value)


@pulumi.type_token("databricks:index/file:File")
class File(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 content_base64: Optional[pulumi.Input[_builtins.str]] = None,
                 md5: Optional[pulumi.Input[_builtins.str]] = None,
                 path: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input[Union['FileProviderConfigArgs', 'FileProviderConfigArgsDict']]] = None,
                 remote_file_modified: Optional[pulumi.Input[_builtins.bool]] = None,
                 source: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        This resource allows uploading and downloading files in databricks_volume.

        > This resource can only be used with a workspace-level provider!

        > Currently the limit is 5GiB in octet-stream.

        > Currently, only UC volumes are supported. The list of destinations may change.

        ## Example Usage

        In order to manage a file on Unity Catalog Volumes with Pulumi, you must specify the `source` attribute containing the full path to the file on the local filesystem.

        ```python
        import pulumi
        import pulumi_databricks as databricks

        sandbox = databricks.Catalog("sandbox",
            metastore_id=this_databricks_metastore["id"],
            name="sandbox",
            comment="this catalog is managed by terraform",
            properties={
                "purpose": "testing",
            })
        things = databricks.Schema("things",
            catalog_name=sandbox.name,
            name="things",
            comment="this schema is managed by terraform",
            properties={
                "kind": "various",
            })
        this = databricks.Volume("this",
            name="quickstart_volume",
            catalog_name=sandbox.name,
            schema_name=things.name,
            volume_type="MANAGED",
            comment="this volume is managed by terraform")
        this_file = databricks.File("this",
            source="/full/path/on/local/system",
            path=this.volume_path.apply(lambda volume_path: f"{volume_path}/fileName"))
        ```

        You can also inline sources through `content_base64`  attribute.

        ```python
        import pulumi
        import pulumi_databricks as databricks
        import pulumi_std as std

        init_script = databricks.File("init_script",
            content_base64=std.base64encode(input=\"\"\"#!/bin/bash
        echo \\"Hello World\\"
        \"\"\").result,
            path=f"{this['volumePath']}/fileName")
        ```

        ## Related Resources

        The following resources are often used in the same context:

        * WorkspaceFile
        * End to end workspace management guide.
        * Volume to manage [volumes within Unity Catalog](https://docs.databricks.com/en/connect/unity-catalog/volumes.html).

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] content_base64: Contents in base 64 format. Conflicts with `source`.
        :param pulumi.Input[_builtins.str] path: The path of the file in which you wish to save. For example, `/Volumes/main/default/volume1/file.txt`.
        :param pulumi.Input[Union['FileProviderConfigArgs', 'FileProviderConfigArgsDict']] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
        :param pulumi.Input[_builtins.str] source: The full absolute path to the file. Conflicts with `content_base64`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: FileArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource allows uploading and downloading files in databricks_volume.

        > This resource can only be used with a workspace-level provider!

        > Currently the limit is 5GiB in octet-stream.

        > Currently, only UC volumes are supported. The list of destinations may change.

        ## Example Usage

        In order to manage a file on Unity Catalog Volumes with Pulumi, you must specify the `source` attribute containing the full path to the file on the local filesystem.

        ```python
        import pulumi
        import pulumi_databricks as databricks

        sandbox = databricks.Catalog("sandbox",
            metastore_id=this_databricks_metastore["id"],
            name="sandbox",
            comment="this catalog is managed by terraform",
            properties={
                "purpose": "testing",
            })
        things = databricks.Schema("things",
            catalog_name=sandbox.name,
            name="things",
            comment="this schema is managed by terraform",
            properties={
                "kind": "various",
            })
        this = databricks.Volume("this",
            name="quickstart_volume",
            catalog_name=sandbox.name,
            schema_name=things.name,
            volume_type="MANAGED",
            comment="this volume is managed by terraform")
        this_file = databricks.File("this",
            source="/full/path/on/local/system",
            path=this.volume_path.apply(lambda volume_path: f"{volume_path}/fileName"))
        ```

        You can also inline sources through `content_base64`  attribute.

        ```python
        import pulumi
        import pulumi_databricks as databricks
        import pulumi_std as std

        init_script = databricks.File("init_script",
            content_base64=std.base64encode(input=\"\"\"#!/bin/bash
        echo \\"Hello World\\"
        \"\"\").result,
            path=f"{this['volumePath']}/fileName")
        ```

        ## Related Resources

        The following resources are often used in the same context:

        * WorkspaceFile
        * End to end workspace management guide.
        * Volume to manage [volumes within Unity Catalog](https://docs.databricks.com/en/connect/unity-catalog/volumes.html).

        :param str resource_name: The name of the resource.
        :param FileArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(FileArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 content_base64: Optional[pulumi.Input[_builtins.str]] = None,
                 md5: Optional[pulumi.Input[_builtins.str]] = None,
                 path: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input[Union['FileProviderConfigArgs', 'FileProviderConfigArgsDict']]] = None,
                 remote_file_modified: Optional[pulumi.Input[_builtins.bool]] = None,
                 source: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = FileArgs.__new__(FileArgs)

            __props__.__dict__["content_base64"] = content_base64
            __props__.__dict__["md5"] = md5
            if path is None and not opts.urn:
                raise TypeError("Missing required property 'path'")
            __props__.__dict__["path"] = path
            __props__.__dict__["provider_config"] = provider_config
            __props__.__dict__["remote_file_modified"] = remote_file_modified
            __props__.__dict__["source"] = source
            __props__.__dict__["file_size"] = None
            __props__.__dict__["modification_time"] = None
        super(File, __self__).__init__(
            'databricks:index/file:File',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            content_base64: Optional[pulumi.Input[_builtins.str]] = None,
            file_size: Optional[pulumi.Input[_builtins.int]] = None,
            md5: Optional[pulumi.Input[_builtins.str]] = None,
            modification_time: Optional[pulumi.Input[_builtins.str]] = None,
            path: Optional[pulumi.Input[_builtins.str]] = None,
            provider_config: Optional[pulumi.Input[Union['FileProviderConfigArgs', 'FileProviderConfigArgsDict']]] = None,
            remote_file_modified: Optional[pulumi.Input[_builtins.bool]] = None,
            source: Optional[pulumi.Input[_builtins.str]] = None) -> 'File':
        """
        Get an existing File resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] content_base64: Contents in base 64 format. Conflicts with `source`.
        :param pulumi.Input[_builtins.int] file_size: The file size of the file that is being tracked by this resource in bytes.
        :param pulumi.Input[_builtins.str] modification_time: The last time stamp when the file was modified
        :param pulumi.Input[_builtins.str] path: The path of the file in which you wish to save. For example, `/Volumes/main/default/volume1/file.txt`.
        :param pulumi.Input[Union['FileProviderConfigArgs', 'FileProviderConfigArgsDict']] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
        :param pulumi.Input[_builtins.str] source: The full absolute path to the file. Conflicts with `content_base64`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _FileState.__new__(_FileState)

        __props__.__dict__["content_base64"] = content_base64
        __props__.__dict__["file_size"] = file_size
        __props__.__dict__["md5"] = md5
        __props__.__dict__["modification_time"] = modification_time
        __props__.__dict__["path"] = path
        __props__.__dict__["provider_config"] = provider_config
        __props__.__dict__["remote_file_modified"] = remote_file_modified
        __props__.__dict__["source"] = source
        return File(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="contentBase64")
    def content_base64(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Contents in base 64 format. Conflicts with `source`.
        """
        return pulumi.get(self, "content_base64")

    @_builtins.property
    @pulumi.getter(name="fileSize")
    def file_size(self) -> pulumi.Output[_builtins.int]:
        """
        The file size of the file that is being tracked by this resource in bytes.
        """
        return pulumi.get(self, "file_size")

    @_builtins.property
    @pulumi.getter
    def md5(self) -> pulumi.Output[Optional[_builtins.str]]:
        return pulumi.get(self, "md5")

    @_builtins.property
    @pulumi.getter(name="modificationTime")
    def modification_time(self) -> pulumi.Output[_builtins.str]:
        """
        The last time stamp when the file was modified
        """
        return pulumi.get(self, "modification_time")

    @_builtins.property
    @pulumi.getter
    def path(self) -> pulumi.Output[_builtins.str]:
        """
        The path of the file in which you wish to save. For example, `/Volumes/main/default/volume1/file.txt`.
        """
        return pulumi.get(self, "path")

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> pulumi.Output[Optional['outputs.FileProviderConfig']]:
        """
        Configure the provider for management through account provider. This block consists of the following fields:
        """
        return pulumi.get(self, "provider_config")

    @_builtins.property
    @pulumi.getter(name="remoteFileModified")
    def remote_file_modified(self) -> pulumi.Output[Optional[_builtins.bool]]:
        return pulumi.get(self, "remote_file_modified")

    @_builtins.property
    @pulumi.getter
    def source(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The full absolute path to the file. Conflicts with `content_base64`.
        """
        return pulumi.get(self, "source")

